==> endeavour_2.3.2.orig.tar.gz: endeavour-2.3.2/endeavour2/hedit/config.h <==
/*
                 Endeavour HEdit Compile Time Configuration
 */

#ifndef CONFIG_HVIEW_H
#define CONFIG_HVIEW_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"Hex Editor"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#ifdef PROG_LANGUAGE_ENGLISH
#define PROG_HELP_MESG  "\
Usage: hedit <file> [options] [GUI_options]\n\
\n\
    <file> specifies the file to edit.\n\
\n\
    [options] can be any of the following:\n\
\n\
        --help                  Prints (this) help screen and exits.\n\
        --version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_SPANISH
#define PROG_HELP_MESG	"\
El uso: hedit <file> [options] [GUI_options]\n\
\n\
    <file> specifies the file to edit.\n\
\n\
    [options] puede ser cualquiera de lo Siguiente:\n\
\n\
        --help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
        --version               Versin Imprime informacin de versin y salidas.\n\
\n\
    [GUI_options] puede ser cualquier estndar de las opcin a su GUI,\n\
    consulta su manual de GUI para opciones disponibles.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_FRENCH
#define PROG_HELP_MESG  "\
L'usage: hedit <file> [options] [GUI_options]\n\
\n\
    <file> specifies the file to edit.\n\
\n\
    [options] peut tre n'importe quel du suivre:\n\
\n\
        --help                  Caractres (ceci) aide cran et sorties.\n\
        --version               Caractres information de version et sorties.\n\
\n\
    [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
    GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
\n"
#endif



/*
 *      Drag and drop target type names and info values:
 */
#define HEDIT_DND_TYPE_INFO_TEXT_PLAIN		0	/* "text/plain" */
#define HEDIT_DND_TYPE_INFO_TEXT_URI_LIST	1	/* "text/uri-list" */
#define HEDIT_DND_TYPE_INFO_STRING		2	/* "STRING" */


#endif	/* CONFIG_HEDIT_H */

==> endeavour_2.4.6.orig.tar.gz: endeavour-2.4.6/endeavour2/hedit/config.h <==
/*
                 Endeavour HEdit Compile Time Configuration
 */

#ifndef CONFIG_HVIEW_H
#define CONFIG_HVIEW_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"Hex Editor"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#ifdef PROG_LANGUAGE_ENGLISH
#define PROG_HELP_MESG  "\
Usage: hedit <file> [options] [GUI_options]\n\
\n\
    <file> specifies the file to edit.\n\
\n\
    [options] can be any of the following:\n\
\n\
        --address <address>     Go to address position at startup.\n\
        --help                  Prints (this) help screen and exits.\n\
        --version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_SPANISH
#define PROG_HELP_MESG	"\
El uso: hedit <file> [options] [GUI_options]\n\
\n\
    <file> specifies the file to edit.\n\
\n\
    [options] puede ser cualquiera de lo Siguiente:\n\
\n\
        --address <address>     La posicin fija de la direccin en inicio.\n\
        --help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
        --version               Versin Imprime informacin de versin y salidas.\n\
\n\
    [GUI_options] puede ser cualquier estndar de las opcin a su GUI,\n\
    consulta su manual de GUI para opciones disponibles.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_FRENCH
#define PROG_HELP_MESG  "\
L'usage: hedit <file> [options] [GUI_options]\n\
\n\
    <file> specifies the file to edit.\n\
\n\
    [options] peut tre n'importe quel du suivre:\n\
\n\
        --address <address>     La position d'adresse de srie au dmarrage.\n\
        --help                  Caractres (ceci) aide cran et sorties.\n\
        --version               Caractres information de version et sorties.\n\
\n\
    [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
    GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
\n"
#endif



/*
 *      Drag and drop target type names and info values:
 */
#define HEDIT_DND_TYPE_INFO_TEXT_PLAIN		0	/* "text/plain" */
#define HEDIT_DND_TYPE_INFO_TEXT_URI_LIST	1	/* "text/uri-list" */
#define HEDIT_DND_TYPE_INFO_STRING		2	/* "STRING" */


#endif	/* CONFIG_HEDIT_H */
